@@ -95,9 +95,11 @@ namespace Banshee.Base
                     Catalog.GetString("Select None"), "<control><shift>A",
                     Catalog.GetString("Unselect all songs in song list"), null),
                 
-                new ActionEntry("PreferencesAction", Stock.Preferences,
-                    Catalog.GetString("Preferences..."), null,
-                    Catalog.GetString("Edit Banshee preferences"), null),
+                new ActionEntry("PluginsAction", null,
+                    Catalog.GetString("Plugins..."), null,
+                    Catalog.GetString("Configure Banshee plugins"), null),
+                
+                new ActionEntry("PreferencesAction", Stock.Preferences, null),
                 
                 new ActionEntry("ViewMenuAction", null,
                     Catalog.GetString("_View"), null, null, null),
@@ -117,9 +119,7 @@ namespace Banshee.Base
                     Catalog.GetString("Version Information..."), null,
                     Catalog.GetString("View detailed version and configuration information"), null),
                     
-                new ActionEntry("AboutAction", "gtk-about",
-                    Catalog.GetString("About..."), null,
-                    Catalog.GetString("View Banshee credits and license information"), null),
+                new ActionEntry("AboutAction", "gtk-about", null),
                     
                 new ActionEntry("PlaybackMenuAction", null,
                     Catalog.GetString("_Playback"), null, null, null),
@@ -172,7 +172,7 @@ namespace Banshee.Base
                     Catalog.GetString("Permanently delete selected song(s) from storage medium"), null),
                     
                 new ActionEntry("PropertiesAction", Stock.Properties,
-                    Catalog.GetString("Properties"), null,
+                    Catalog.GetString("Edit Song Metadata"), null,
                     Catalog.GetString("Edit metadata on selected songs"), null),
                     
                 new ActionEntry("AddToPlaylistAction", null,
