@@ -51,6 +51,7 @@ namespace Banshee.Sources
             this.device = device;
             device.SaveStarted += OnDapSaveStarted;
             device.SaveFinished += OnDapSaveFinished;
+            device.Reactivate += OnDapReactivate;
             CanRename = device.CanSetName;
         }
         
@@ -119,6 +120,12 @@ namespace Banshee.Sources
             
             OnViewChanged();
         }
+        
+        private void OnDapReactivate(object o, EventArgs args)
+        {
+            OnViewChanged();
+            OnUpdated();
+        }
 
         public override int Count {
             get {
@@ -202,7 +209,7 @@ namespace Banshee.Sources
         
         public override Gtk.Widget ViewWidget {
             get {
-                return IsSyncing ? syncing_container : null;
+                return IsSyncing ? syncing_container : Device.ViewWidget;
             }
         }
         
@@ -211,5 +218,11 @@ namespace Banshee.Sources
                 return !IsSyncing;
             }
         }
+        
+        public override bool SearchEnabled {
+            get {
+                return !IsSyncing && Device.ViewWidget == null;
+            }
+        }
     }
 }
