@@ -133,11 +133,12 @@ namespace Banshee.Base
         }
         
         [DllImport("libc")]
-        private static extern int prctl(int option, byte [] arg2, ulong arg3 , ulong arg4, ulong arg5);
+        private static extern int prctl(int option, byte [] arg2, IntPtr arg3, IntPtr arg4, IntPtr arg5);
         
         public static void SetProcessName(string name)
         {
-            if(prctl(15 /* PR_SET_NAME */, Encoding.ASCII.GetBytes(name), 0, 0, 0) != 0) {
+            if(prctl(15 /* PR_SET_NAME */, Encoding.ASCII.GetBytes(name + "\0"), 
+                IntPtr.Zero, IntPtr.Zero, IntPtr.Zero) != 0) {
                 throw new ApplicationException("Error setting process name: " + 
                     Mono.Unix.Native.Stdlib.GetLastError());
             }
