@@ -690,7 +690,7 @@ namespace Banshee
             trackInfoHeader.Title = ti.DisplayTitle;
             trackInfoHeader.Album = ti.DisplayAlbum;
             
-            WindowPlayer.Title = ti.DisplayTitle + " - " + Catalog.GetString("Banshee");
+            WindowPlayer.Title = ti.DisplayTitle + " (" + ti.DisplayArtist + ")";
             
             try {
                 trackInfoHeader.Cover.FileName = ti.CoverArtFileName;
@@ -1075,6 +1075,9 @@ namespace Banshee
                 if(playlistModel.Count() == 0 && args.Source.Count > 0) {
                     playlistModel.ReloadSource();
                 }
+                
+                gxml["SearchLabel"].Sensitive = args.Source.SearchEnabled;
+                searchEntry.Sensitive = gxml["SearchLabel"].Sensitive;
             }
         }
         
@@ -1232,6 +1235,7 @@ namespace Banshee
             audiocd_statusbar.Pixbuf = icon;
         }
         
+        // Called when SourceManager emits an ActiveSourceChanged event.
         private void HandleSourceChanged(object o, EventArgs args)
         {
             Source source = SourceManager.ActiveSource;
@@ -1250,22 +1254,24 @@ namespace Banshee
                 UpdateAudioCdStatus(cdSource.Disk);
             }
             
-            UpdateViewName(source);
-            SensitizeActions(source);
+            UpdateViewName(source);   // Bold label below track info
+            SensitizeActions(source); // Right-click actions, buttons above search
 
-            if(source is DapSource) {
+            if(source is DapSource) { // Show disk usage bar for DAPs
                 gxml["DapContainer"].ShowAll();
                 sync_dap_button.Pixbuf = (source as DapSource).Device.GetIcon(22);
             } else {
                 gxml["DapContainer"].Hide();
             }
             
-            gxml["SearchLabel"].Sensitive = !(source is AudioCdSource);
+            // Make some choices for audio CDs, they can't be rated, nor have plays or
+            // last-played info. Only show the rip button for audio CDs
+            gxml["SearchLabel"].Sensitive = source.SearchEnabled;
             searchEntry.Sensitive = gxml["SearchLabel"].Sensitive;
             playlistView.RipColumn.Visible = source is AudioCdSource;
-            playlistView.RatingColumn.Visible = !(source is AudioCdSource);
-            playlistView.PlaysColumn.Visible = playlistView.RatingColumn.Visible;
-            playlistView.LastPlayedColumn.Visible = playlistView.RatingColumn.Visible;
+            playlistView.RatingColumn.Hidden = (source is AudioCdSource);
+            playlistView.PlaysColumn.Hidden = (source is AudioCdSource);
+            playlistView.LastPlayedColumn.Hidden = (source is AudioCdSource);
                 
             UpdateSourceView();
                 
@@ -1380,13 +1386,7 @@ namespace Banshee
                 if(count == 0 && SourceManager.ActiveSource == null) {
                     LabelStatusBar.Text = Catalog.GetString("Banshee Music Player");
                 } else if(count == 0) {
-                    if(SourceManager.ActiveSource is LibrarySource) {
-                        LabelStatusBar.Text = Catalog.GetString(
-                           "Your Library is Empty - Consider Importing Music");
-                    } else if(SourceManager.ActiveSource is PlaylistSource) {
-                        LabelStatusBar.Text = Catalog.GetString(
-                            "This Playlist is Empty - Consider Adding Music");
-                    }
+                    LabelStatusBar.Text = String.Empty;
                 } else {
                     string text = String.Format(Catalog.GetPluralString("{0} Item", "{0} Items", 
                         (int)count), count) + ", ";
@@ -1535,6 +1535,8 @@ namespace Banshee
                     continue;
                 }
             }
+            
+            playlistView.UpdateView();
         }
         
         // PlaylistView DnD
