@@ -179,7 +179,8 @@ namespace Banshee
         [Method]
         public virtual string GetPlayingCoverUri()
         {
-            return HaveTrack ? PlayerUI.ActiveTrackInfo.CoverArtFileName : String.Empty;
+            string cover = HaveTrack ? PlayerUI.ActiveTrackInfo.CoverArtFileName : String.Empty;
+            return cover == null ? String.Empty : cover;
         }
         
         [Method]
@@ -194,12 +195,6 @@ namespace Banshee
             return HaveTrack ? (int)PlayerEngineCore.ActivePlayer.Position : -1;
         }
         
-        [Method]
-        public virtual string GetPlayingCoverArtFileName()
-        {
-            return HaveTrack ? PlayerUI.ActiveTrackInfo.CoverArtFileName : String.Empty;
-        }
-        
         [Method]
         public virtual int GetPlayingStatus()
         {
